#!/usr/bin/env sh

#
# Copyright(c) 2006-2016 ThreatSTOP, Inc. All Rights Reserved
#
# NOTICE: All information contained herein is, and remains the property
# of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
# technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
# and its suppliers and certain aspects thereof are protected by United 
# States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
# and are protected by trade secret or copyright law.
#
# US Government Entities: The ThreatSTOP service, software and
# documentation, as applicable, are "commercial computer software" and
# "commercial computer software documentation" developed exclusively at
# private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
# 12.212 or DFARS 227 7202 and their successors, as applicable, use,
# reproduction and disclosure of the software and documentation is
# governed by the terms of Threatstop's commercial agreement.
#

#
# ThreatSTOP OpenBSD PF Install Script
# This script copies the scripts to /usr/local/sbin and the configuration file
# to /usr/local/etc. If the files exist, you will be prompted on whether you
# to replace the files. It is recommended that you do not overwrite the 
# configuration file and merge the threatstop.conf.example file with your 
# current file.
#
# The script also creates 2 cron jobs. The first is running the script that
# updates the block lists, threatstop-pf.sh. This will run every 2 hours. The 
# second uploads the log file to ThreatSTOP. This runs every night at 1:00 AM.
# In order to prevent duplicate log entries, the log file needs to be rotated
# at least once a day. This script updates the pflog entry in /etc/newsyslog.conf
# to rotate the log ever night at 12:00 AM and removes the size check.
#
###############################################################################

PREFIX="/usr/local"

# Check to make sure script is run by root
if [ `id -u` != "0" ]
then
        echo "You must run the script as root. Exiting" 
        exit 1
fi

# Make sure the directories exist. Create if needed.
if [ ! -d $PREFIX/sbin ]
then
        echo "$PREFIX/sbin does not exist. Creating."
        mkdir -p $PREFIX/sbin
fi

if [ ! -d $PREFIX/etc ]
then
        echo "$PREFIX/etc does not exist. Creating"
        mkdir -p $PREFIX/etc
fi

# Copy the scripts to $PREFIX/sbin
echo "Copying scripts to \"$PREFIX/sbin\""
cp -i threatstop-pf.sh sendlog.sh loguploadclient.pl ptr.sed apl.sed $PREFIX/sbin

# Copy the configuration file to $PREFIX/etc
echo;echo "Copying configuration and version file to \"$PREFIX/etc\""
cp -i threatstop.conf $PREFIX/etc
cp -i VERSION $PREFIX/etc/threatstop.VERSION

# Create the cron jobs
echo;echo "Adding crontab entry to run the \"threatstop-pf.sh\" script every 2 hours"
echo "and upload the log file with the \"sendlog.sh\" script every day at 1:00 AM"
echo "  Backing up original crontab to \"crontab.original\""
crontab -l > crontab.original	# Make a copy
cp crontab.original newcrontab	# Create working file from the backup
MIN=`date +%M`
# Append new jobs to the working file
cat >> newcrontab <<CRONTAB

# ThreatSTOP update
$MIN      */2     *       *       *       /usr/local/sbin/threatstop-pf.sh
0       1       *       *       *       /usr/local/sbin/sendlog.sh
CRONTAB

crontab newcrontab	# Replace crontab with new file
rm newcrontab		# Delete the working file

# Change newsyslog to rotate the pflog file at midnight
echo;echo "Changing the newsyslog.conf file to rotate pflog every day at 12:00 AM"
echo "  Creating backup of newsyslog.conf"
cp /etc/newsyslog.conf /etc/newsyslog.conf.threatstop
sed '/pflog/ s/[0-9]*[ ]*\*[ ]*ZB/*    $D0   ZB/' < /etc/newsyslog.conf.threatstop > /etc/newsyslog.conf

