#!/usr/bin/perl
#
# Copyright(c) 2006-2016 ThreatSTOP, Inc. All Rights Reserved
#
# NOTICE: All information contained herein is, and remains the property
# of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
# technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
# and its suppliers and certain aspects thereof are protected by United 
# States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
# and are protected by trade secret or copyright law.
#
# US Government Entities: The ThreatSTOP service, software and
# documentation, as applicable, are "commercial computer software" and
# "commercial computer software documentation" developed exclusively at
# private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
# 12.212 or DFARS 227 7202 and their successors, as applicable, use,
# reproduction and disclosure of the software and documentation is
# governed by the terms of Threatstop's commercial agreement.
#

#
#ThreatSTOP log upload script partly borrowed from the internet

chomp(my $VERSION=`cat /usr/local/etc/threatstop.VERSION`);
# file: loguploadclient.pl
# takes no arguments. logfile and url to upload in threatstop.conf
# outputs messages to /tmp/tsoutput.txt
#
###############################################################################
use strict;
use LWP::UserAgent;
use HTTP::Request::Common;
use Digest::MD5;

my %cfg;
my $path=substr($0,0,rindex($0,'/')+1);
my $t=gmtime;
open (OUT, '>/tmp/tsoutput.txt');
print OUT "$0 started at $t\n";
open (FILE, '</usr/local/etc/threatstop.conf') or die "can't find threatstop config file";
while (<FILE>) {
	#print $_;
	next unless (/^([a-z]\w+)=[("]?(.*?)[")]?\s+$/);
	$cfg{$1}=$2; 
}
close FILE;

# Build md5-checksum as hexdigest
my $local_md5 = undef;
my $ctx = Digest::MD5->new;

# read file for that
open (MD,$cfg{'logfile'});
# build MD5
my $ctx = Digest::MD5->new;
$ctx->addfile(*MD);
close MD;
$local_md5 = $ctx->hexdigest;
# End of md5

my $filesize = (stat $cfg{'logfile'})[7];

# print "log size $filesize md5 $local_md5\n";

my $ua  = LWP::UserAgent->new();

sub poster {
	# put timeouts, proxy etc into the useragent if needed
	my $req = POST $cfg{'url'}, Content_Type => 'form-data',
		Content      => [
			submit => 1,
			upfile_size => $filesize,
			upfile =>  [ $cfg{'logfile'} ],
			md5_client => $local_md5
		];
	my $response = $ua->request($req);
	return $response;
}

for (my $try =0;$try<5;$try++) {
	my $resp = poster();
	if ($resp->is_success()) {
		print OUT "Probably OK on $try try", $resp->content.$/;
		next unless ($resp->content =~/MD5: OK\s+Filesize: OK/s);
		last;
	}
	print OUT "Failed on try $try: ".$resp->as_string.$/;
}
close OUT;

open LOG, '/tmp/tsoutput.txt';
while (<LOG>) {
	if ($_ =~ /MD5:\sOK/) {
		print "Log file uploaded successfully\n";
	}
	elsif ($_ =~ /4\stry.*Denied/) {
		print "\nLog file was not uploaded. Please contact support for assistance\n";
		print "support\@threatstop.com\n";
		print "1-760-542-1440\n";
	}
}
close LOG;
exit;

