#!/usr/bin/env sh

#
# Copyright(c) 2006-2016 ThreatSTOP, Inc. All Rights Reserved
#
# NOTICE: All information contained herein is, and remains the property
# of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
# technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
# and its suppliers and certain aspects thereof are protected by United 
# States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
# and are protected by trade secret or copyright law.
#
# US Government Entities: The ThreatSTOP service, software and
# documentation, as applicable, are "commercial computer software" and
# "commercial computer software documentation" developed exclusively at
# private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
# 12.212 or DFARS 227 7202 and their successors, as applicable, use,
# reproduction and disclosure of the software and documentation is
# governed by the terms of Threatstop's commercial agreement.
#

#
# ThreatSTOP OpenBSD PF Log Uploading Script
#
# Send PF log file to ThreatSTOP. The log file is converted to text
# and uploaded to ThreatSTOP using the loguploadclient.pl Perl script.
# File is POSTed to the ThreatSTOP HTTPS website.
#
# This script must be run as root due to premissions placed on the pflog
# files.
#
# Script works with logs that are compressed and not compressed. The PFLOG 
# setting in the threatstop.conf file is the pflog that will be converted 
# to text. By default, the configuration is set to look for the last rotated 
# file, named /var/log/pflog.0 by default.
#
###############################################################################


PREFIX="/usr/local"
CONFIG="$PREFIX/etc/threatstop.conf"
WORKDIR="/tmp"

# Check for and read the config file, abort if not found
if [ ! -f $CONFIG ]
then
	echo "ALERT: Cannot read config file: \"$CONFIG\" Exiting"
	exit 1
else
	. $CONFIG
fi

# Check to make sure script is run by root
if [ `id -u` != "0" ]
then
	echo "You must run the script as root. Exiting" 
	exit 1
fi

# Check to see if the file is compressed.
if [ -f $PFLOG ]
then
	# not compressed
	cp $PFLOG $WORKDIR
elif [ -f $PFLOG.gz ]
then
	# compressed
	cp $PFLOG.gz $WORKDIR
	GZLOG=`basename $WORKDIR/pflog.0.gz`
	gunzip $WORKDIR/$GZLOG
else
	echo "file not found. aborting"
	exit 1
fi

LOG="$WORKDIR/pflog.0"

# use tcpdump to dump log to a file
tcpdump -n -e -ttt -r $LOG 2>/dev/null > $logfile 

# Run log upload Perl script
perl $PREFIX/sbin/loguploadclient.pl

# delete work files
rm $WORKDIR/pflog.0 $logfile

